@@ -68,6 +68,9 @@ class TaskWrapper():
         self.scheduled_time = scheduled_time
         self.frequency = frequency
         self.trigger = trigger
+        self.log_dir = os.path.join(cwd, 'logs')
+
+        self.init_log_dir()
 
     def execute(self):
         print("Executing script")
@@ -77,8 +80,23 @@ class TaskWrapper():
         # info.dwFlags = subprocess.STARTUPINFO()
         # info.wShowWindow = SW_MINIMIZE
         p = subprocess.Popen(['python3', filepath], cwd=self.cwd) #, startupinfo=info)
-        # stdout, stderr = p.communicate()
+        stdout, stderr = p.communicate()
+        log_time = datetime.strftime(datetime.now(), '%Y%m%d-%hh%mm%ss')
+        log_file_stdout = os.path.join(self.log_dir, log_time, "stdout.txt")
+        log_file_stderr = os.path.join(self.log_dir, log_time, "stdout.txt")
+        
+        with open(log_file_stdout, "w") as log_file:
+            log_file.write(stdout)
+
+        with open(log_file_stderr, "w") as log_file:
+            log_file.write(stderr)
+
         return p
+
+    def init_log_dir(self):
+        if not os.path.isdir(self.log_dir):
+            os.makedirs(self.log_dir)
+
     
 
 class Task():
@@ -362,4 +380,8 @@ def take_screenshot_save(save_location):
     # time.sleep(3)
     save_path = ''.join([save_location, "/img/aai_", ''.join(choice(digits) for i in range(12)), ".png"])
     im = pyautogui.screenshot(save_path)
-    print("Done")
\ No newline at end of file
+    print("Done")
+
+
+def _get_theme_path():
+    return theme_path
\ No newline at end of file
